@@ -20,11 +20,13 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#error "Only <clutter/clutter.h> can be included directly."
+#endif
+
 #ifndef __CLUTTER_BEHAVIOUR_OPACITY_H__
 #define __CLUTTER_BEHAVIOUR_OPACITY_H__
 
@@ -58,7 +60,15 @@ G_BEGIN_DECLS
 typedef struct _ClutterBehaviourOpacity        ClutterBehaviourOpacity;
 typedef struct _ClutterBehaviourOpacityPrivate ClutterBehaviourOpacityPrivate;
 typedef struct _ClutterBehaviourOpacityClass   ClutterBehaviourOpacityClass;
- 
+
+/**
+ * ClutterBehaviourOpacity:
+ *
+ * The #ClutterBehaviourOpacity structure contains only private data and
+ * should be accessed using the provided API
+ *
+ * Since: 0.2
+ */
 struct _ClutterBehaviourOpacity
 {
   /*< private >*/
@@ -66,8 +76,16 @@ struct _ClutterBehaviourOpacity
   ClutterBehaviourOpacityPrivate *priv;
 };
 
+/**
+ * ClutterBehaviourOpacityClass:
+ *
+ * The #ClutterBehaviourOpacityClas structure contains only private data
+ *
+ * Since: 0.2
+ */
 struct _ClutterBehaviourOpacityClass
 {
+  /*< private >*/
   ClutterBehaviourClass   parent_class;
 };
 
