@@ -18,9 +18,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 /**
@@ -34,12 +34,6 @@
  * clutter_texture_set_from_file() functions are used to copy image
  * data into texture memory and subsequently realize the texture.
  *
- * If texture reads are supported by underlying GL implementation,
- * unrealizing frees image data from texture memory moving to main
- * system memory. Re-realizing then performs the opposite operation.
- * This process allows basic management of commonly limited available
- * texture memory.
- *
  * Note: a ClutterTexture will scale its contents to fit the bounding
  * box requested using clutter_actor_set_size(). To display an area of
  * a texture without scaling, you should set the clip area using
@@ -86,16 +80,9 @@ struct _ClutterTexturePrivate
   ClutterActor                *fbo_source;
   CoglHandle                   fbo_handle;
 
-  /* Non video memory copy of image data */
-  guint                        local_data_width, local_data_height;
-  guint                        local_data_rowstride;
-  guint                        local_data_has_alpha;
-  guchar                      *local_data;
-
   guint                        sync_actor_size : 1;
   guint                        repeat_x : 1;
   guint                        repeat_y : 1;
-  guint                        in_dispose : 1;
   guint                        keep_aspect_ratio : 1;
   guint                        load_size_async : 1;
   guint                        load_data_async : 1;
@@ -172,12 +159,6 @@ static GStaticMutex upload_list_mutex = G_STATIC_MUTEX_INIT;
 static void
 texture_fbo_free_resources (ClutterTexture *texture);
 
-static void
-clutter_texture_save_to_local_data (ClutterTexture *texture);
-
-static void
-clutter_texture_load_from_local_data (ClutterTexture *texture);
-
 GQuark
 clutter_texture_error_quark (void)
 {
@@ -241,14 +222,6 @@ clutter_texture_unrealize (ClutterActor *actor)
   if (priv->material == COGL_INVALID_HANDLE)
     return;
 
-  /* there's no need to read the pixels back when unrealizing inside
-   * a dispose run, and the dispose() call will release the GL
-   * texture data as well, so we can safely bail out now
-   */
-  if ((CLUTTER_PRIVATE_FLAGS (actor) & CLUTTER_ACTOR_IN_DESTRUCTION) ||
-      priv->in_dispose)
-    return;
-
   CLUTTER_MARK();
 
   if (priv->fbo_source != NULL)
@@ -260,24 +233,6 @@ clutter_texture_unrealize (ClutterActor *actor)
       return;
     }
 
-  if (clutter_feature_available (CLUTTER_FEATURE_TEXTURE_READ_PIXELS))
-    {
-      /* Move image data from video to main memory.
-       * GL/ES cant do this - it probably makes sense
-       * to move this kind of thing into a ClutterProxyTexture
-       * where this behaviour can be better controlled.
-       *
-       * Or make it controllable via a property.
-       */
-      if (priv->local_data == NULL)
-	{
-	  clutter_texture_save_to_local_data (texture);
-	  CLUTTER_NOTE (TEXTURE, "moved pixels into system mem");
-	}
-
-      texture_free_gl_resources (texture);
-    }
-
   CLUTTER_NOTE (TEXTURE, "Texture unrealized");
 }
 
@@ -327,25 +282,15 @@ clutter_texture_realize (ClutterActor *actor)
       return;
     }
 
-  if (priv->local_data != NULL)
-    {
-      /* Move any local image data we have from unrealization
-       * back into video memory.
-      */
-      clutter_texture_load_from_local_data (texture);
-    }
-  else
-    {
-      /* If we have no data, then realization is a no-op but
-       * we still want to be in REALIZED state to maintain
-       * invariants. We may have already created the texture
-       * if someone set some data earlier, or we may create it
-       * later if someone sets some data later. The fact that
-       * we may have created it earlier is really a bug, since
-       * it means ClutterTexture can have GL resources without
-       * being realized.
-       */
-    }
+  /* If the texture is not a FBO, then realization is a no-op but we
+   * still want to be in REALIZED state to maintain invariants.
+   * ClutterTexture doesn't need to be realized to have a Cogl texture
+   * because Clutter assumes that a GL context is always current so
+   * there is no need to wait to realization time to create the
+   * texture. Although this is slightly odd it would be wasteful to
+   * redundantly store a copy of the texture data in local memory just
+   * so that we can make a texture during realize.
+   */
 
   CLUTTER_NOTE (TEXTURE, "Texture realized");
 }
@@ -701,27 +646,10 @@ static void
 clutter_texture_dispose (GObject *object)
 {
   ClutterTexture *texture = CLUTTER_TEXTURE (object);
-  ClutterTexturePrivate *priv;
-
-  priv = texture->priv;
-
-  /* mark that we are in dispose, so when the parent class'
-   * dispose implementation will call unrealize on us we'll
-   * not try to copy back the resources from video memory
-   * to system memory
-   */
-  if (!priv->in_dispose)
-    priv->in_dispose = TRUE;
 
   texture_free_gl_resources (texture);
   texture_fbo_free_resources (texture);
 
-  if (priv->local_data != NULL)
-    {
-      g_free (priv->local_data);
-      priv->local_data = NULL;
-    }
-
   clutter_texture_async_load_cancel (texture);
 
   G_OBJECT_CLASS (clutter_texture_parent_class)->dispose (object);
@@ -1177,78 +1105,9 @@ clutter_texture_init (ClutterTexture *self)
   priv->sync_actor_size   = TRUE;
   priv->material          = cogl_material_new ();
   priv->fbo_handle        = COGL_INVALID_HANDLE;
-  priv->local_data        = NULL;
   priv->keep_aspect_ratio = FALSE;
 }
 
-static void
-clutter_texture_save_to_local_data (ClutterTexture *texture)
-{
-  ClutterTexturePrivate *priv;
-  int                    bpp;
-  CoglPixelFormat        pixel_format;
-  CoglHandle             cogl_texture;
-
-  priv = texture->priv;
-
-  if (priv->local_data)
-    {
-      g_free (priv->local_data);
-      priv->local_data = NULL;
-    }
-
-  if (priv->material == COGL_INVALID_HANDLE)
-    return;
-
-  cogl_texture = clutter_texture_get_cogl_texture (texture);
-
-  priv->local_data_width = cogl_texture_get_width (cogl_texture);
-  priv->local_data_height = cogl_texture_get_height (cogl_texture);
-  pixel_format = cogl_texture_get_format (cogl_texture);
-  priv->local_data_has_alpha = pixel_format & COGL_A_BIT;
-  bpp = priv->local_data_has_alpha ? 4 : 3;
-
-  /* Align to 4 bytes */
-  priv->local_data_rowstride = (priv->local_data_width * bpp + 3) & ~3;
-
-  priv->local_data = g_malloc (priv->local_data_rowstride
-			       * priv->local_data_height);
-
-  if (cogl_texture_get_data (cogl_texture,
-			     priv->local_data_has_alpha
-			     ? COGL_PIXEL_FORMAT_RGBA_8888_PRE
-			     : COGL_PIXEL_FORMAT_RGB_888,
-			     priv->local_data_rowstride,
-			     priv->local_data) == 0)
-    {
-      g_free (priv->local_data);
-      priv->local_data = NULL;
-    }
-}
-
-static void
-clutter_texture_load_from_local_data (ClutterTexture *texture)
-{
-  ClutterTexturePrivate *priv;
-
-  priv = texture->priv;
-
-  if (priv->local_data == NULL)
-    return;
-
-  clutter_texture_set_from_rgb_data (texture,
-				     priv->local_data,
-				     priv->local_data_has_alpha,
-				     priv->local_data_width,
-				     priv->local_data_height,
-				     priv->local_data_rowstride,
-				     priv->local_data_has_alpha ? 4: 3,
-				     CLUTTER_TEXTURE_RGB_FLAG_PREMULT, NULL);
-
-  g_free (priv->local_data);
-  priv->local_data = NULL;
-}
-
 /**
  * clutter_texture_get_cogl_material:
  * @texture: A #ClutterTexture
@@ -1352,12 +1211,6 @@ clutter_texture_get_cogl_texture (ClutterTexture *texture)
  * @cogl_tex. A reference to the texture is taken so if the handle is
  * no longer needed it should be deref'd with cogl_handle_unref.
  *
- * This should not be called on an unrealizable texture (one that
- * isn't inside a stage). (Currently the ClutterTexture
- * implementation relies on being able to have a GL texture while
- * unrealized, which means you can get away with it, but it's
- * not correct and may change in the future.)
- *
  * Since: 0.8
  */
 void
@@ -1371,11 +1224,10 @@ clutter_texture_set_cogl_texture (ClutterTexture  *texture,
   g_return_if_fail (CLUTTER_IS_TEXTURE (texture));
   g_return_if_fail (cogl_is_texture (cogl_tex));
 
-  /* FIXME this implementation should realize the actor if it's in a
-   * stage, and warn and return if not in a stage yet. However, right
-   * now everything would break if we did that, so we just fudge it
-   * and we're broken: we can have a texture without being realized.
-   */
+  /* This function can set the texture without the actor being
+     realized. This is ok because Clutter requires that the GL context
+     always be current so there is no point in waiting to realization
+     to set the texture. */
 
   priv = texture->priv;
 
@@ -1393,15 +1245,7 @@ clutter_texture_set_cogl_texture (ClutterTexture  *texture,
   /* Remove old texture */
   texture_free_gl_resources (texture);
 
-  /* Free any saved data so realization doesn't resend it to GL */
-  if (priv->local_data)
-    {
-      g_free (priv->local_data);
-      priv->local_data = NULL;
-    }
-
   /* Use the new texture */
-
   cogl_material_set_layer (priv->material, 0, cogl_tex);
 
   /* The material now holds a reference to the texture so we can
@@ -1432,8 +1276,7 @@ clutter_texture_set_cogl_texture (ClutterTexture  *texture,
   g_object_notify (G_OBJECT (texture), "cogl-texture");
 
   /* If resized actor may need resizing but paint() will do this */
-  if (CLUTTER_ACTOR_IS_VISIBLE (texture))
-    clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
+  clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
 }
 
 static gboolean
@@ -1520,13 +1363,10 @@ clutter_texture_set_from_rgb_data (ClutterTexture       *texture,
 				   ClutterTextureFlags   flags,
 				   GError              **error)
 {
-  ClutterTexturePrivate *priv;
   CoglPixelFormat source_format;
 
   g_return_val_if_fail (CLUTTER_IS_TEXTURE (texture), FALSE);
 
-  priv = texture->priv;
-
   /* Convert the flags to a CoglPixelFormat */
   if (has_alpha)
     {
@@ -1595,8 +1435,6 @@ clutter_texture_set_from_yuv_data (ClutterTexture     *texture,
 				   ClutterTextureFlags flags,
 				   GError            **error)
 {
-  ClutterTexturePrivate *priv;
-
   g_return_val_if_fail (CLUTTER_IS_TEXTURE (texture), FALSE);
 
   if (!clutter_feature_available (CLUTTER_FEATURE_TEXTURE_YUV))
@@ -1607,8 +1445,6 @@ clutter_texture_set_from_yuv_data (ClutterTexture     *texture,
       return FALSE;
     }
 
-  priv = texture->priv;
-
   /* Convert the flags to a CoglPixelFormat */
   if ((flags & CLUTTER_TEXTURE_YUV_FLAG_YUV2))
     {
@@ -2029,8 +1865,7 @@ clutter_texture_set_filter_quality (ClutterTexture        *texture,
 
       g_object_notify (G_OBJECT (texture), "filter-quality");
 
-      if (CLUTTER_ACTOR_IS_VISIBLE (texture))
-	clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
+      clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
     }
 }
 
@@ -2203,11 +2038,8 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
                                         ClutterTextureFlags flags,
                                         GError            **error)
 {
-  ClutterTexturePrivate *priv;
-  CoglPixelFormat        source_format;
-  CoglHandle             cogl_texture;
-
-  priv = texture->priv;
+  CoglPixelFormat source_format;
+  CoglHandle cogl_texture;
 
   if (has_alpha)
     {
@@ -2218,6 +2050,7 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
 		       "Unsupported BPP");
 	  return FALSE;
 	}
+
       source_format = COGL_PIXEL_FORMAT_RGBA_8888;
     }
   else
@@ -2229,17 +2062,22 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
 		       "Unsupported BPP");
 	  return FALSE;
 	}
+
       source_format = COGL_PIXEL_FORMAT_RGB_888;
     }
+
   if ((flags & CLUTTER_TEXTURE_RGB_FLAG_BGR))
     source_format |= COGL_BGR_BIT;
+
   if ((flags & CLUTTER_TEXTURE_RGB_FLAG_PREMULT))
     source_format |= COGL_PREMULT_BIT;
 
   /* attempt to realize ... */
   if (!CLUTTER_ACTOR_IS_REALIZED (texture) &&
       clutter_actor_get_stage (CLUTTER_ACTOR (texture)) != NULL)
-    clutter_actor_realize (CLUTTER_ACTOR (texture));
+    {
+      clutter_actor_realize (CLUTTER_ACTOR (texture));
+    }
 
   /* due to the fudging of clutter_texture_set_cogl_texture()
    * which allows setting a texture pre-realize, we may end
@@ -2271,8 +2109,7 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
   /* rename signal */
   g_signal_emit (texture, texture_signals[PIXBUF_CHANGE], 0);
 
-  if (CLUTTER_ACTOR_IS_VISIBLE (texture))
-    clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
+  clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
 
   return TRUE;
 }
