@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifndef __COGL_DEBUG_H__
@@ -29,26 +29,24 @@
 G_BEGIN_DECLS
 
 typedef enum {
-  COGL_DEBUG_MISC             = 1 << 0,
-  COGL_DEBUG_TEXTURE          = 1 << 1,
-  COGL_DEBUG_MATERIAL         = 1 << 2,
-  COGL_DEBUG_SHADER           = 1 << 3,
-  COGL_DEBUG_OFFSCREEN        = 1 << 4,
-  COGL_DEBUG_DRAW             = 1 << 5,
-  COGL_DEBUG_PANGO            = 1 << 6,
-  COGL_DEBUG_RECTANGLES       = 1 << 7,
-  COGL_DEBUG_HANDLE           = 1 << 8,
-  COGL_DEBUG_BLEND_STRINGS    = 1 << 9,
-  COGL_DEBUG_DISABLE_BATCHING = 1 << 10,
-  COGL_DEBUG_DISABLE_VBOS     = 1 << 11,
-  COGL_DEBUG_JOURNAL          = 1 << 12,
-  COGL_DEBUG_BATCHING         = 1 << 13,
-  COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM = 1 << 14,
-  COGL_DEBUG_MATRICES         = 1 << 15,
-  COGL_DEBUG_FORCE_SCANLINE_PATHS = 1 << 16,
-  COGL_DEBUG_ATLAS            = 1 << 17,
-  COGL_DEBUG_DUMP_ATLAS_IMAGE = 1 << 18,
-  COGL_DEBUG_DISABLE_ATLAS    = 1 << 19
+  COGL_DEBUG_SLICING          = 1 << 1,
+  COGL_DEBUG_OFFSCREEN        = 1 << 2,
+  COGL_DEBUG_DRAW             = 1 << 3,
+  COGL_DEBUG_PANGO            = 1 << 4,
+  COGL_DEBUG_RECTANGLES       = 1 << 5,
+  COGL_DEBUG_HANDLE           = 1 << 6,
+  COGL_DEBUG_BLEND_STRINGS    = 1 << 7,
+  COGL_DEBUG_DISABLE_BATCHING = 1 << 8,
+  COGL_DEBUG_DISABLE_VBOS     = 1 << 9,
+  COGL_DEBUG_JOURNAL          = 1 << 10,
+  COGL_DEBUG_BATCHING         = 1 << 11,
+  COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM = 1 << 12,
+  COGL_DEBUG_MATRICES         = 1 << 13,
+  COGL_DEBUG_FORCE_SCANLINE_PATHS = 1 << 14,
+  COGL_DEBUG_ATLAS            = 1 << 15,
+  COGL_DEBUG_DUMP_ATLAS_IMAGE = 1 << 16,
+  COGL_DEBUG_DISABLE_ATLAS    = 1 << 17,
+  COGL_DEBUG_OPENGL           = 1 << 18
 } CoglDebugFlags;
 
 #ifdef COGL_ENABLE_DEBUG
@@ -62,7 +60,7 @@ typedef enum {
 #else
 #define COGL_NOTE(type,...)                     G_STMT_START {  \
         if (cogl_debug_flags & COGL_DEBUG_##type) {             \
-          gchar *_fmt = g_strdup_printf (__VA_ARGS__);          \
+          char *_fmt = g_strdup_printf (__VA_ARGS__);          \
           g_message ("[" #type "] " G_STRLOC ": %s", _fmt);     \
           g_free (_fmt);                                        \
         }                                       } G_STMT_END
@@ -75,7 +73,7 @@ typedef enum {
 
 #endif /* COGL_ENABLE_DEBUG */
 
-extern guint cogl_debug_flags;
+extern unsigned int cogl_debug_flags;
 
 G_END_DECLS
 
